@@ -1,19 +1,21 @@
 ################################################################################
 
 .onLoad <- function(libname, pkgname) {
-  options(
+
+  pkg.opt <- list(
     bigstatsr.ncores.max          = parallel::detectCores(),
     bigstatsr.check.parallel.blas = TRUE
   )
+
+  toset <- !(names(pkg.opt) %in% names(.Options))
+  if (any(toset)) options(pkg.opt[toset])
 }
 
 ################################################################################
 
 .onUnload <- function(libpath) {
   options(
-    bigstatsr.ncores.max          = NULL,
-    bigstatsr.check.parallel.blas = NULL,
-    default.nproc.blas            = NULL
+    default.nproc.blas = NULL
   )
 }
 
